/*  Gringotts - a small utility to safe-keep sensitive data
 *  (c) 2002, Germano Rizzo <mano@pluto.linux.it>
 *
 *  libgrg_crypt.h - internal-use (opaque) parameters definition
 *  Author: Germano Rizzo
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef LIBGRG_CRYPT_H
#define LIBGRG_CRYPT_H

#include <stdio.h>

#include "libgringotts.h"

struct grg_token {
	FILE *rnd;
	unsigned char *header;
	unsigned char hlen;
	grg_crypt_algo crypt_algo;
	grg_hash_algo hash_algo;
	grg_comp_algo comp_algo;
	grg_comp_ratio comp_lvl;
	grg_security_lvl sec_lvl;
};

//use of small memory requirements in BZ2 decompression
#define USE_BZ2_SMALL_MEM		TRUE

//file format specs; do not touch these
#define GRG_FILE_VERSION		"2"
#define MAX_COMP_SIZE			8	//in Mb

#define GRG_FILE_VERSION_LEN	1
#define GRG_CRC_LEN				4
#define GRG_DATA_DIM_LEN		4
#define GRG_ALGO_LEN			1
#define GRG_OVERHEAD			GRG_FILE_VERSION_LEN+GRG_CRC_LEN*2+GRG_ALGO_LEN+GRG_DATA_DIM_LEN

#define GRG_IV_SIZE_MIN			8	//for 3DES
#define GRG_IV_SIZE_MAX			32	//for RIJNDAEL_256

#define FALSE	0
#define TRUE	!FALSE

#endif
